California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Go to Section:
| Statewide Candidates
| State Senate Candidates
| State Assembly Candidates
Choose an Election: 2022 PRIMARY 2021 SPECIAL ELECTION (ASSEMBLY 54) Prior Elections 2021 SPECIAL ELECTION (ASSEMBLY 79) 2021 SPECIAL ELECTION (STATE SENATE 30) 2020 GENERAL 2020 SPECIAL RUNOFF (STATE SENATE 28) 2020 PRIMARY 2020 SPECIAL ELECTION (STATE SENATE 28) 2019 SPECIAL RUNOFF (ASSEMBLY 01) 2019 SPECIAL ELECTION (ASSEMBLY 01) 2019 SPECIAL RUNOFF (STATE SENATE 01) 2019 SPECIAL RUNOFF (STATE SENATE 33) 2019 SPECIAL ELECTION (STATE SENATE 01) 2019 SPECIAL ELECTION (STATE SENATE 33) 2018 GENERAL 2018 SPECIAL RUNOFF (STATE SENATE 32) 2018 PRIMARY 2018 SPECIAL ELECTION (STATE SENATE 32) 2018 SPECIAL ELECTION (STATE SENATE 29) 2018 SPECIAL RUNOFF (ASSEMBLY 45) 2018 SPECIAL RUNOFF (ASSEMBLY 39) 2018 SPECIAL ELECTION (ASSEMBLY 45) 2018 SPECIAL ELECTION (ASSEMBLY 54) 2018 SPECIAL ELECTION (ASSEMBLY 39) 2017 SPECIAL RUNOFF (ASSEMBLY 51) 2017 SPECIAL ELECTION (ASSEMBLY 51) 2016 GENERAL 2016 PRIMARY 2016 SPECIAL ELECTION (ASSEMBLY 31) 2015 SPECIAL RUNOFF (STATE SENATE 07) 2015 SPECIAL ELECTION (STATE SENATE 37) 2015 SPECIAL ELECTION (STATE SENATE 21) 2015 SPECIAL ELECTION (STATE SENATE 07) 2014 SPECIAL ELECTION (STATE SENATE 35) 2014 GENERAL 2014 PRIMARY 2014 SPECIAL ELECTION (STATE SENATE 23) 2013 SPECIAL ELECTION (ASSEMBLY 54) 2013 SPECIAL RUNOFF (ASSEMBLY 45) 2013 SPECIAL RUNOFF (ASSEMBLY 52) 2013 SPECIAL ELECTION (STATE SENATE 26) 2013 SPECIAL ELECTION (ASSEMBLY 45) 2013 SPECIAL ELECTION (ASSEMBLY 52) 2013 SPECIAL RUNOFF (STATE SENATE 16) 2013 SPECIAL ELECTION (ASSEMBLY 80) 2013 SPECIAL ELECTION (STATE SENATE 16) 2013 SPECIAL RUNOFF (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 40) 2013 SPECIAL ELECTION (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 04) 2012 GENERAL 2012 SPECIAL ELECTION (STATE SENATE 04) 2012 PRIMARY 2011 SPECIAL RUNOFF (ASSEMBLY 04) 2011 SPECIAL ELECTION (ASSEMBLY 04) 2011 SPECIAL ELECTION (STATE SENATE 17) 2011 SPECIAL ELECTION (STATE SENATE 28) 2011 SPECIAL RUNOFF (STATE SENATE 01) 2010 GENERAL 2010 SPECIAL ELECTION (STATE SENATE 01) 2010 SPECIAL RUNOFF (STATE SENATE 15) 2010 SPECIAL ELECTION (STATE SENATE 15) 2010 PRIMARY 2010 SPECIAL RUNOFF (STATE SENATE 37) 2010 SPECIAL RUNOFF (ASSEMBLY 43) 2010 SPECIAL ELECTION (STATE SENATE 37) 2010 SPECIAL ELECTION (ASSEMBLY 43) 2010 SPECIAL RUNOFF (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 51) 2009 SPECIAL RUNOFF (STATE SENATE 26) 2009 SPECIAL ELECTION (STATE SENATE 26) 2008 GENERAL 2008 PRIMARY 2008 RECALL (STATE SENATE 12) 2008 SPECIAL RUNOFF (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 39) 2006 GENERAL 2006 PRIMARY 2006 SPECIAL RUNOFF (STATE SENATE 35) 2006 SPECIAL ELECTION (STATE SENATE 35) 2005 SPECIAL ELECTION (ASSEMBLY 53) 2004 GENERAL 2004 PRIMARY 2003 SPECIAL ELECTION (GOVERNOR) 2002 GENERAL 2002 PRIMARY 2001 SPECIAL ELECTION (ASSEMBLY 49) 2001 SPECIAL RUNOFF (ASSEMBLY 65) 2001 SPECIAL ELECTION (STATE SENATE 24) 2001 SPECIAL ELECTION (ASSEMBLY 65) 2000 GENERAL 2000 PRIMARY
Also check Late Contribution filings. These reports are independent of the comprehensive disclosure reports that are linked here until semi-annual filings are submitted.
STATEWIDE OFFICES
GOVERNOR
AGBEDE, AKINYEMI O. ALLEN, TRAVIS ARREOLA, ARMANDO M AVORY, SHEAR (WITHDRAWN) BRIBIESCA, JUAN M. CARES, THOMAS J. CARLSON, CHRIS CHIANG, JOHN COX, JOHN H. EASTIN, DELAINE FIMBRES, VERONIKA GIRARD, YVONNE R. GOEL, SHUBHAM GRIFFIS, ROBERT D. GYURKO, ZOLTAN ISTVAN JONES, JOSHUA G. LA RIVA, GLORIA E. LIU, PETER Y. MEZZETTI, ALBERT C. MIKADO, HAKAN A. NEWMAN II, ROBERT C. NEWSOM, GAVIN PEARCE, K. RENTERIA, AMANDA SHELLENBERGER, MICHAEL D. SILVEIRA, DESMOND A. SOLTANI, ARMAN TAYLOR, JEFFREY E. TINAJ, KLEMENT VALENTINO, PETER CRAWFORD VILLARAIGOSA, ANTONIO R. WATTENBURG, JOHNNY WILDSTAR, NICKOLAS
| LIEUTENANT GOVERNOR
BLEICH, JEFF FARIBA, MARJAN FENNELL, DAVID D. FERREIRA, TIMOTHY J. GHARABIKLOU, CAMERON J. HARRIS, COLE M. HERNANDEZ, DAVID HERNANDEZ, EDWARD P. KOUNALAKIS, ELENI MC LAUGHLIN, GAYLE ORTEGA, LYDIA D. THOMAS, DANNY
SECRETARY OF STATE
FEINSTEIN, MICHAEL ALAN LIGHTFOOT, GAIL K. MAJOR, RUBEN K. MEUSER, MARK P. PADILLA, ALEX RODRIGUEZ JR., RAUL RYDBERG, ERIK B. WEBER, C.T.
| CONTROLLER
FINLEY, MARY LOU RODITIS, KONSTANTINOS YEE, BETTY T.
TREASURER
AKIN, KEVIN D. CONLON, GREG GUERRERO, JACK M. MA, FIONA VISWANATHAN, VIVEK
| ATTORNEY GENERAL
BAILEY, STEVEN BECERRA, XAVIER EARLY, ERIC JONES, DAVE
SUPERINTENDENT OF PUBLIC INSTRUCTION
IRELAND, STEVEN LEE PLOSKI, LILY E. THURMOND, TONY TUCK, MARSHALL VIGIL, DOUGLAS I. WILLIAMS, THOMAS L.
| INSURANCE COMMISSIONER
HRIZI, NATHALIE LARA, RICARDO MAHMOOD, ASIF POIZNER, STEVE
BOARD OF EQUALIZATION
MEMBER BOARD OF EQUALIZATION 01
CONWAY, CONNIE EVANS, DAVID GAINES, EDWARD T HALLINAN, TOM
| MEMBER BOARD OF EQUALIZATION 02
BURNS, MARK CHANG, BARRY COHEN, MALIA M. GALGIANI, CATHLEEN
MEMBER BOARD OF EQUALIZATION 03
KRIEGEL, DOUG MARSHALL, G. RICK O'LEARY, MICHEAL A. PAK, BEN PEARLMAN, NANCY S. SVONKIN, SCOTT TURNER, CHERYL C. VAZQUEZ, ANTONIO
| MEMBER BOARD OF EQUALIZATION 04
ANDERSON, JOEL C. DODSON, DAVID B. KELLY, JOHN LOPEZ-MADDOX, KENNETH W. SCHAEFER, J. MICHAEL SHAHATIT, NADER F STIERINGER, JAMES G.
SENATE DISTRICTS
STATE SENATE 02
JACOBI, VERONICA S. MC GUIRE, MIKE
| STATE SENATE 04
KIM, PHILLIP J. NIELSEN, JIM WORLEY, MICHAEL
STATE SENATE 06
BENNETT, AUSTIN DE ROSE, JANINE L. FRAME, ERIC S.T. MASON, JACOB PAN, RICHARD
| STATE SENATE 08
BELDEN, MARK BORGEAS, ANDREAS MIRANDA, PAULINA M. PRATT, TOM
STATE SENATE 10
SAN VICENTE, VICTOR SARSAK, ALI A. WIECKOWSKI, ROBERT
| STATE SENATE 12
BRAZIL, DENNIS CABALLERO, ANNA PARRA, DANIEL POYTHRESS, ROBERT L. TACHERRA, JOHNNY
STATE SENATE 14
HURTADO, MELISSA MACARENO, RUBEN SOLIS, ABIGAIL VIDAK, JAMES ANDREW
| STATE SENATE 16
GROVE, SHANNON MUSSER-LOPEZ, RUTH TATUM, GREGORY
STATE SENATE 18
HERTZBERG, ROBERT MELENDEZ, RUDY SAARIO, BRANDON SAYEGH, ROGER J.
| STATE SENATE 20
AVILA, PAUL VINCENT LEYVA, CONNIE M. MUNSON, MATTHEW G.
STATE SENATE 22
ENG, MICHAEL GARCIA, RAQUEL 'MONICA' RUBIO, SUSAN SIERRA, RUBEN
| STATE SENATE 24
CHOI, PETER DURAZO, MARIA ELENA
STATE SENATE 26
ALLEN, BEN BRUNO, BARON HERD, MARK MATTHEW
| STATE SENATE 28
NEVENIC, ANNA SILVER, JOY STONE, JEFFREY E.
STATE SENATE 30
MITCHELL, HOLLY J.
| STATE SENATE 32
ARCHULETA, BOB BERMUDEZ, RUDY CASTELLANOS, DAVID DELGADO, VANESSA MENDOZA, TONY ROMERO, VIVIAN SANTANA, VICKY SAREGA, ION TAJ, ALI SAJJAD TOPALIAN, RITA H.
STATE SENATE 34
HAWKINS, AKASH A. NGUYEN, JANET SAMSON, JESTIN L. UMBERG, THOMAS J.
| STATE SENATE 36
BATES, PATRICIA 'PAT' CASTELLANO, MARGGIE
STATE SENATE 38
GRIFFITH, JEFF D. JONES, BRIAN W. SALGUERO, ANTONIO
| STATE SENATE 40
HUESO, BEN VARGAS, LUIS R.
ASSEMBLY DISTRICTS
ASSEMBLY 01
DAHLE, BRIAN O'CONNELL-NOWAIN, JENNY L. SISK, CALEEN A. VAN PEBORGH, PETER FOSS VENUS, JEROME B.C.
| ASSEMBLY 02
HEATH, MATTHEW D. WOOD, JIM
ASSEMBLY 03
AERY, SONIA GALLAGHER, JAMES
| ASSEMBLY 04
AGUIAR-CURRY, CECILIA FULTON, SARAH JOAN NELSON, BRANDON Z. NUTTING, CHERYLYN A.
ASSEMBLY 05
BIGELOW, FRANK NEAL, CARLA J
| ASSEMBLY 06
KILEY, KEVIN SMITH, JACKIE
ASSEMBLY 07
MC CARTY, KEVIN SCHMIDT, SCOTT
| ASSEMBLY 08
AVEY, MELINDA M. BONSER, JANICE M. COOLEY, KEN MURRAY, LAWRENCE "LARRY" R.
ASSEMBLY 09
COOPER, JIM GARCIA, MARIO A. HE, HARRY SUM
| ASSEMBLY 10
LEVINE, MARC MONTE, DAN
ASSEMBLY 11
FRAZIER, JR., JAMES L ROMERO, LISA C. STEWART, DIANE D.
| ASSEMBLY 12
CHASE, ROBERT D FLORA, HEATH
ASSEMBLY 13
EGGMAN, SUSAN GARCIA, ANTONIO M. VILLAPUDUA, CARLOS
| ASSEMBLY 14
GRAYSON, TIM YAHYA, AASIM
ASSEMBLY 15
APPEL, JUDY BARTLETT, BEN BECKLES, JOVANKA JANDHYALA, PRANAV KALB, DAN E. KATZ, ANDY PARDUE-OKIMOTO, ROCHELLE PITERMAN, SERGEY R. POINDEXTER, OWEN SUDDUTH, CHERYL THAMAN, RAQUELLA M. WICKS, BUFFY
| ASSEMBLY 16
BAKER, CATHARINE BAUER-KAHAN, REBECCA
ASSEMBLY 17
CHIU, DAVID FERNANDEZ, ALEJANDRO
| ASSEMBLY 18
BONTA, ROB SLAUSON, STEVE
ASSEMBLY 19
BOGDON, KEITH R ERNST, DAVID S. TING, PHIL
| ASSEMBLY 20
GRCAR, JOSEPH QUIRK, BILL
ASSEMBLY 21
GRAY, ADAM C. QUIGLEY, JUSTIN RYAN
| ASSEMBLY 22
DUFFY, BRIDGET LASKOWSKI, CHRISTINA MULLIN, KEVIN C.
ASSEMBLY 23
PATTERSON, JIM RIZO, AILEEN M.
| ASSEMBLY 24
BERMAN, MARC GLEW, ALEXANDER GOODWYN, ROBERT D.
ASSEMBLY 25
BRUNTON, ROBERT L. CHU, KANSEN IMHOFF-DOUSHARM, ROBERT V. MONTANO, CARMEN
| ASSEMBLY 26
GUBLER, WARREN LAVERS, JACK J. MATHIS, DEVON J. SIGALA, JOSE
ASSEMBLY 27
KALRA, ASH LANCASTER, G. BURT
| ASSEMBLY 28
LOW, EVAN SNYDER, MICHAEL L.
ASSEMBLY 29
NOHRDEN, VICKI L. STONE, MARK
| ASSEMBLY 30
COFFMAN-GOMEZ, TRINA KITCHENS, NEIL G. LEROE-MUNOZ, PETER B. LIPE, BILL RIVAS, ROBERT
ASSEMBLY 31
ARAMBULA, JOAQUIN ESPINOZA, LUPE
| ASSEMBLY 32
MENDES, JUSTIN SALAS JR., RUDY
ASSEMBLY 33
CISNEROS, SOCORO MARKOVICH, PETER SCOTT OBERNOLTE, JAY
| ASSEMBLY 34
FONG, VINCENT NICITA, NICHOLAS J.
ASSEMBLY 35
CUNNINGHAM, JORDAN OSTRANDER, WILLIAM J.
| ASSEMBLY 36
FOX, STEVE LACKEY, THOMAS W.
ASSEMBLY 37
COLLIN, SOFIA M. LIMON, S. MONIQUE NORRDIN, DAVID L.
| ASSEMBLY 38
ACOSTA, DANTE SMITH, CHRISTY
ASSEMBLY 39
BENITEZ, RICARDO CORWIN, BONNIE D. LOPEZ, PATTY PATRICK, PATREA RIVAS, LUZ SANCHEZ, ANTONIO
| ASSEMBLY 40
COOK, LIBBERN GWEN NICKEL, HENRY RAMOS, JAMES
ASSEMBLY 41
HOLDEN, CHRIS REYNOLDS, ALAN S. ROTTER, KENNETH M.
| ASSEMBLY 42
BOULDIN, CAROL A. JEANDRON, GARY KOTYUK, ANDREW F. MAYES, CHAD MAZINGO, DENIANTIONETTE J.
ASSEMBLY 43
FRIEDMAN, LAURA
| ASSEMBLY 44
BALDWIN-KENNEDY, RONDA N. IRWIN, JACQUI V. ZELINSKY, ROBERT M.
ASSEMBLY 45
BISHOP, RAYMOND J. BORNSTEIN, JEFF S. BRIN, DANIEL CLARK, JUSTIN M. GABRIEL, JESSE PATEL, ANKUR ROBBINS KASSON, TRICIA
| ASSEMBLY 46
HOGE, ROXANNE E.B. NAZARIAN, ADRIN
ASSEMBLY 47
REYES, ELOISE GOMEZ
| ASSEMBLY 48
RUBIO, BLANCA
ASSEMBLY 49
BRINK, BURTON CHAU, ED
| ASSEMBLY 50
BLOOM, RICHARD
ASSEMBLY 51
CARRILLO, WENDY STARE, CHRISTOPHER
| ASSEMBLY 52
GIBBINS, BEN W. GUZMAN, FRANK C. HOLLE, TONI M. RODRIGUEZ, FREDDIE
ASSEMBLY 53
HENRY, RAE E. JANG, KEVIN H. LEWIS, MICHAEL A. SANTIAGO, MIGUEL
| ASSEMBLY 54
DUNWOODY, STEVE HOLLIE, BREON DUPREE KAMLAGER, SYDNEY LYONS, LAMAR A. PIQUADO, TEPRING MICHELLE RATCLIFF, GLEN
ASSEMBLY 55
CHEN, PHILLIP FAZLI, MELISSA FRITCHLE, GREGG D. GERBUS, JAMES G. LEBDA, SCOTT M.
| ASSEMBLY 56
GARCIA, EDUARDO GONZALEZ, JEFFREY REISS, JONATHAN
ASSEMBLY 57
CALDERON, IAN CARTER, BLAKE S. LLAMAS, OSCAR J. MARTINEZ, JESSICA VALERO, JUSTIN J.
| ASSEMBLY 58
ACEITUNO, PEDRO ALTAMIRANO, IVAN ALVARADO, MIGUEL ANGEL DRAYER, JOHN PAUL GARCIA, CRISTINA MEDRANO, FRINE SALAZAR, KARLA SIMPFENDERFER, MIKE
ASSEMBLY 59
HAGAN-MORGAN, LESLIE JONES-SAWYER SR., REGINALD BYRON
| ASSEMBLY 60
CERVANTES, SABRINA ESSAYLI, BILAL 'BILL'
ASSEMBLY 61
MAZAREI, ALI MEDINA, JOSE J.
| ASSEMBLY 62
BURKE, AUTUMN HERNANDEZ, AL L.
ASSEMBLY 63
ESTRADA, MARIA MILLER, ADAM J. RENDON, ANTHONY
| ASSEMBLY 64
GIPSON, MIKE SANFORD, THERESA
ASSEMBLY 65
CORONADO, ALEXANDRIA QUIRK-SILVA, SHARON
| ASSEMBLY 66
ARNOLD, CANEY MURATSUCHI, AL SCOTTO, FRANK
ASSEMBLY 67
MELENDEZ, MELISSA SINGLETON, MICHELLE D.
| ASSEMBLY 68
CHOI, STEVEN DUMAN, MICHELLE
ASSEMBLY 69
BROWNE, AUTUMN DALY, TOM
| ASSEMBLY 70
BRUHNKE, RACHEL A. GONZALES, ELLIOT R. O'DONNELL, PATRICK ROBSON, HONOR MIMI
ASSEMBLY 71
ELIA, JAMES M. VOEPEL, RANDY G. WILSKE, LARRY A.
| ASSEMBLY 72
DIEP, TYLER HASKIN, GREG LAIRD, RICHARD LOWENTHAL, JOSH PHAM, LONG K.
ASSEMBLY 73
BROUGH, WILLIAM (BILL) RHINEHART, SCOTT SACHS, ED
| ASSEMBLY 74
DAIGLE, KATHERINE HARPER, MATTHEW ONOFRE, KARINA PETRIE-NORRIS, COTTIE TA, RYAN D
ASSEMBLY 75
GERACI, ALAN WALDRON, MARIE
| ASSEMBLY 76
BOERNER HORVATH, TASHA GRAHAM, PHIL E. KROUSE, THOMAS MUIR, MAUREEN "MO" M. RIGBY, AMANDA STOCKS, JEROME B. WARREN, ELIZABETH WIMMER, BRIAN J.
ASSEMBLY 77
GOVER, SUNDAY MAIENSCHEIN, BRIAN
| ASSEMBLY 78
CAMPBELL, MAGGIE GLORIA, TODD
ASSEMBLY 79
MOORE, JOHN S. WEBER, SHIRLEY
| ASSEMBLY 80
GONZALEZ, LORENA S. PICKARD, LINCOLN M. VIVEIROS, JOSEPH